==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Downloads/language/lang-brazilian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","Link");
define("_PREVIOUS","Pgina Anterior");
define("_NEXT","Pgina Posterior");
define("_CATEGORY","Categoria");
define("_CATEGORIES","Categorias");
define("_LVOTES","votos");
define("_TOTALVOTES","Total de Votos:");
define("_THEREARE","H");
define("_NOMATCHES","Nada encontrado para");
define("_SCOMMENTS","Comentrios");
define("_UNKNOWN","Desconhecido");
define("_DOWNLOADS","downloads");
define("_AUTHORNAME","Nome do Autor");
define("_AUTHOREMAIL","Email do Autor");
define("_DOWNLOADNAME","Nome do Programa");
define("_ADDTHISFILE","Adicionar este arquivo");
define("_INBYTES","em bytes");
define("_FILESIZE","Tamanho");
define("_VERSION","Verso");
define("_DESCRIPTION","Descrio");
define("_AUTHOR","Autor");
define("_HOMEPAGE","Home-Page");
define("_DOWNLOADNOW","Baixe este arquivo agora!");
define("_RATERESOURCE","Taxa do Recurso");
define("_FILEURL","Link do Arquivo");
define("_ADDDOWNLOAD","Adicionar Download");
define("_DOWNLOADSMAIN","ndice Downloads");
define("_DOWNLOADCOMMENTS","Comentrios sobre Download");
define("_DOWNLOADSMAINCAT","ndice de categorias para Download");
define("_ADDADOWNLOAD","Adicionar um novo Download");
define("_DSUBMITONCE","Envie um arquivo novo somente um vez.");
define("_DPOSTPENDING","Todos os Downloads tem uma verificao.");
define("_RESSORTED","Recursos atualmente ordenados por");
define("_DOWNLOADSNOTUSER1","Voc no  um usurio registrado ou no efetuou seu login.");
define("_DOWNLOADSNOTUSER2","Se voc fosse um usurio registrado poderia enviar arquivos para downloads neste site.");
define("_DOWNLOADSNOTUSER3","Para se tornar um usurio registrado o processo  rpido e fcil.");
define("_DOWNLOADSNOTUSER4","Por que ns requeremos o seu registro para acessar certas reas?");
define("_DOWNLOADSNOTUSER5","Porque s assim poderemos lhe oferecer um contedo da mais alta qualidade,");
define("_DOWNLOADSNOTUSER6","pois cada item  revisado individualmente por nossa equipe.");
define("_DOWNLOADSNOTUSER7","E ns desejamos lhe oferecer somente informaes importantes.");
define("_DOWNLOADSNOTUSER8","<a href=\"modules.php?name=Your_Account\">Registre uma Conta</a>");
define("_DOWNLOADALREADYEXT","ERRO: Esta URL j existe no Banco de Dados!");
define("_DOWNLOADNOTITLE","ERRO: Voc precisa digitar um ttulo para sua URL!");
define("_DOWNLOADNOURL","ERRO: Voc precisa digitar uma URL para sua URL!");
define("_DOWNLOADNODESC","ERRO: Voc precisa digitar uma descrio para sua URL!");
define("_DOWNLOADRECEIVED","Ns recebemos o envio do seu arquivo. Obrigado!");
define("_NEWDOWNLOADS","Novos Downloads");
define("_TOTALNEWDOWNLOADS","Total de Novos Downloads");
define("_DTOTALFORLAST","Total de novos downloads enviados por ltimos");
define("_DBESTRATED","Downloads melhores posicionados - Top");
define("_TRATEDDOWNLOADS","total de downloads taxados");
define("_SORTDOWNLOADSBY","Tipo de Download");
define("_DCATNEWTODAY","Novos Downloads nesta categoria adicionados Hoje");
define("_DCATLAST3DAYS","Novos Downloads nesta categoria adicionados nos ltimos 3 dias");
define("_DCATTHISWEEK","Novos Downloads nesta categoria adicionados nesta semana");
define("_DDATE1","Data (Downloads Antigos Listados Primeiro)");
define("_DDATE2","Data (Downloads Novos Listados Primeiro)");
define("_DOWNLOADPROFILE","Perfil do Download");
define("_DOWNLOADRATINGDET","Detalhes das Taxas de Download");
define("_EDITTHISDOWNLOAD","Editar este Download");
define("_DOWNLOADRATING","Taxando Download");
define("_DOWNLOADVOTE","Vote!");
define("_REQUESTDOWNLOADMOD","Pedido para modificao de Download");
define("_DOWNLOADID","Download ID");
define("_DLETSDECIDE","Recomendao de usurios como voc ajudar melhor a outros visitantes a fazer um download de determinado arquivo ento click aqui.");
define("_DRATENOTE4","Voc pode ver uma lista do<a href=\"modules.php?name=Downloads&amp;d_op=TopRated\">Dos Arquivos Mais Avaliados</a>.");
define("_DATE","Data");
define("_TO","Para");
define("_NEW","Novo");
define("_POPULAR","Popular");
define("_TOPRATED","Melhor Colocado");
define("_ADDITIONALDET","Detalhes Adicionais");
define("_EDITORREVIEW","Editor da Reviso");
define("_REPORTBROKEN","Reporte Links Invlidos");
define("_AND","e");
define("_INDB","em nosso Banco de Dados");
define("_INSTRUCTIONS","Instrues");
define("_USERANDIP","So registrado o nome do usurio bem como o ip de quem enviou o Link, ento por favor no abuse ns podemos encontra-lo.");
define("_LDESCRIPTION","Descrio: (255 mx. caracteres)");
define("_CHECKFORIT","Voc no escreveu seu Email. De qualquer maneira nossa equipe ir conferir o seu Link");
define("_LASTWEEK","Da ltima Semana");
define("_LAST30DAYS","Dos ltimos 30 dias");
define("_1WEEK","1 Semana");
define("_2WEEKS","2 Semanas");
define("_30DAYS","30 Dias");
define("_SHOW","Mostar");
define("_DAYS","dias");
define("_ADDEDON","Adicionado em");
define("_RATING","Pdium");
define("_DETAILS","Detalhes");
define("_OF","do");
define("_TVOTESREQ","mnimo de votos requeridos");
define("_SHOWTOP","Mostrar Top");
define("_MOSTPOPULAR","Os Mais Populares - Top");
define("_OFALL","de todos");
define("_POPULARITY","Popularidade");
define("_SELECTPAGE","Pgina Selecionado");
define("_MAIN","ndice");
define("_NEWTODAY","Novo de Hoje");
define("_NEWLAST3DAYS","Novo dos ltimos 3 dias");
define("_NEWTHISWEEK","Novo desta Semana");
define("_POPULARITY1","Popular (Mais Visitados Primeiro)");
define("_POPULARITY2","Popular (Mais Visitados por ltimos)");
define("_TITLEAZ","Ttulo (A a Z)");
define("_TITLEZA","Ttulo (Z a A)");
define("_RATING1","Classificao (Da Pontuao mais Baixa para Mais Alta)");
define("_RATING2","Classificao (Da Pontuao mais Alta para Mais Baixa)");
define("_SEARCHRESULTS4","Resultado da busca por");
define("_USUBCATEGORIES","Subcategorias");
define("_TRY2SEARCH","Experimente Procurar");
define("_INOTHERSENGINES","em outros sistemas de busca");
define("_EDITORIAL","Editorial");
define("_EDITORIALBY","Editorial por");
define("_NOEDITORIAL","Nenhum editorial est atualmente disponvel para este site.");
define("_RATETHISSITE","Classifique este Recurso");
define("_ISTHISYOURSITE","Este  o seu Recurso?");
define("_ALLOWTORATE","Permita que os outros usurios classifiquem isto apartir do seu site !");
define("_OVERALLRATING","Avaliao Global");
define("_TOTALOF","Total de");
define("_USER","Usurios");
define("_USERAVGRATING","A avaliao mdia do usurio");
define("_NUMRATINGS","# de Avaliaes");
define("_REGISTEREDUSERS","Usurios Registrados");
define("_NUMBEROFRATINGS","Nmero de Avaliaes");
define("_NOREGUSERSVOTES","Nenhum usurio annimo vota");
define("_BREAKDOWNBYVAL","Desarranjo de Avaliaes por valor");
define("_LTOTALVOTES","total de votos");
define("_HIGHRATING","Avaliao Alta");
define("_LOWRATING","Avaliao Baixa");
define("_NUMOFCOMMENTS","Nmero de Comentrios");
define("_WEIGHNOTE","* Nota: Este recurso conta para usurios registrados. Avaliao de usurio annimos");
define("_NOUNREGUSERSVOTES","Nenhum usurio annimo vota");
define("_WEIGHOUTNOTE","* Nota: Este recurso pesa para usurios registrados. Fora a avaliao dos eleitores");
define("_NOOUTSIDEVOTES","Nenhum voto Annimo");
define("_OUTSIDEVOTERS","Votos Annimos");
define("_UNREGISTEREDUSERS","Usurios Annimos");
define("_PROMOTEYOURSITE","Promova seu Site");
define("_PROMOTE01","Talvez voc possa se interessar por alguns dos nossos sistemas de 'Avaliao de Sites' que possumos. Estes sistemas permitem colocar uma imagem (ou at mesmo uma forma de avaliao) em seu site na Web de modo que possa aumentar o nmero de visitar que voc recebe. Por favor selecione uma das opes listada abaixo:");
define("_TEXTLINK","Texto Link");
define("_PROMOTE02","Uma maneira de lincar a forma de avaliao  usar um link de texto simples:");
define("_HTMLCODE1","O cdigo em HTML que voc deveria usar neste caso,  o seguinte:");
define("_THENUMBER","Um nmero");
define("_IDREFER","em HTML referente ao nmero de indentificao do seu site que no banco de dados do $sitename. Esteja seguro que este nmero esteja presente.");
define("_BUTTONLINK","Boto do Link");
define("_PROMOTE03","Se voc est procurando um pouco mais que Link de texto simples, talvez voc queira um link com boto pequeno:");
define("_RATEIT","Avalie Este Site!");
define("_HTMLCODE2","O cdigo fonte para o boto acima :");
define("_REMOTEFORM","Forma de Avaliao a Distncia");
define("_PROMOTE04","Se voc nos enganar, ns removeremos seu link. Temos dito isto, aqui como uma forma de avaliao remota e sria.");
define("_VOTE4THISSITE","Vote neste Site!");
define("_HTMLCODE3","Usando desta forma permite que os usurios avaliem o contedo da sua pgina direto do seu site e esta avaliao ser armazenada aqui. A forma acima  invlida, mas o cdigo fonte seguinte funciona basta que voc copie e cole na sua home-page. O cdigo fonte  mostrado abaixo:");
define("_PROMOTE05","Obrigado! E boa sorte com suas avaliaes!");
define("_STAFF","Equipe");
define("_THANKSBROKEN","Obrigado por manter a integridade deste diretrio.");
define("_SECURITYBROKEN","Por razes de segurano seu Nome e Endereo de IP sero gravados temporariamente.");
define("_THANKSFORINFO","Obrigado pela Informao.");
define("_LOOKTOREQUEST","Nossa equipe olhar em breve seu pedido.");
define("_SENDREQUEST","Enviar Pedido");
define("_THANKSTOTAKETIME","Obrigado por usar seu tempo para avaliar um site aqui a");
define("_RETURNTO","Voltar para");
define("_RATENOTE1","Por favor no vote por mais de uma vez na mesma avaliao.");
define("_RATENOTE2","A escala vai de 1 - 10, sendo 1 para pobre e 10 para excelente.");
define("_RATENOTE3","Por favor seja objetivo no seu voto, pois se todo mundo receber somente 1 ou somente 10, as avaliaes no sero teis.");
define("_RATENOTE5","No vote em voc mesmo ou em qualquer um.");
define("_YOUAREREGGED","Voc  um usurio registrado e est conectado em.");
define("_FEELFREE2ADD","Sinta-se a vontade para adicionar comentrios a este site.");
define("_YOUARENOTREGGED","Voc no  um usurio registrado ou no efetuou sue login.");
define("_IFYOUWEREREG","Se voc fosse um usurio registrado poderia enviar vrios comentrios a este site.");
define("_TITLE","Ttulo");
define("_MODIFY","Modificar");
define("_COMPLETEVOTE1","Your vote is appreciated.");
define("_COMPLETEVOTE2","You have already voted for this resource in the past $anonwaitdays day(s).");
define("_COMPLETEVOTE3","Vote for a resource only once.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE4","You cannot vote on a link you submitted.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE5","No rating selected - no vote tallied");
define("_COMPLETEVOTE6","Only one vote per IP address allowed every $outsidewaitdays day(s).");
define("_LINKSDATESTRING","%d-%b-%Y");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Downloads/language/lang-brazilian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","Link");
define("_PREVIOUS","Pgina Anterior");
define("_NEXT","Pgina Posterior");
define("_CATEGORY","Categoria");
define("_CATEGORIES","Categorias");
define("_LVOTES","votos");
define("_TOTALVOTES","Total de Votos:");
define("_THEREARE","H");
define("_NOMATCHES","Nada encontrado para");
define("_SCOMMENTS","Comentrios");
define("_UNKNOWN","Desconhecido");
define("_DOWNLOADS","downloads");
define("_AUTHORNAME","Nome do Autor");
define("_AUTHOREMAIL","Email do Autor");
define("_DOWNLOADNAME","Nome do Programa");
define("_ADDTHISFILE","Adicionar este arquivo");
define("_INBYTES","em bytes");
define("_FILESIZE","Tamanho");
define("_VERSION","Verso");
define("_DESCRIPTION","Descrio");
define("_AUTHOR","Autor");
define("_HOMEPAGE","Home-Page");
define("_DOWNLOADNOW","Baixe este arquivo agora!");
define("_RATERESOURCE","Taxa do Recurso");
define("_FILEURL","Link do Arquivo");
define("_ADDDOWNLOAD","Adicionar Download");
define("_DOWNLOADSMAIN","ndice Downloads");
define("_DOWNLOADCOMMENTS","Comentrios sobre Download");
define("_DOWNLOADSMAINCAT","ndice de categorias para Download");
define("_ADDADOWNLOAD","Adicionar um novo Download");
define("_DSUBMITONCE","Envie um arquivo novo somente um vez.");
define("_DPOSTPENDING","Todos os Downloads tem uma verificao.");
define("_RESSORTED","Recursos atualmente ordenados por");
define("_DOWNLOADSNOTUSER1","Voc no  um usurio registrado ou no efetuou seu login.");
define("_DOWNLOADSNOTUSER2","Se voc fosse um usurio registrado poderia enviar arquivos para downloads neste site.");
define("_DOWNLOADSNOTUSER3","Para se tornar um usurio registrado o processo  rpido e fcil.");
define("_DOWNLOADSNOTUSER4","Por que ns requeremos o seu registro para acessar certas reas?");
define("_DOWNLOADSNOTUSER5","Porque s assim poderemos lhe oferecer um contedo da mais alta qualidade,");
define("_DOWNLOADSNOTUSER6","pois cada item  revisado individualmente por nossa equipe.");
define("_DOWNLOADSNOTUSER7","E ns desejamos lhe oferecer somente informaes importantes.");
define("_DOWNLOADSNOTUSER8","<a href=\"modules.php?name=Your_Account\">Registre uma Conta</a>");
define("_DOWNLOADALREADYEXT","ERRO: Esta URL j existe no Banco de Dados!");
define("_DOWNLOADNOTITLE","ERRO: Voc precisa digitar um ttulo para sua URL!");
define("_DOWNLOADNOURL","ERRO: Voc precisa digitar uma URL para sua URL!");
define("_DOWNLOADNODESC","ERRO: Voc precisa digitar uma descrio para sua URL!");
define("_DOWNLOADRECEIVED","Ns recebemos o envio do seu arquivo. Obrigado!");
define("_NEWDOWNLOADS","Novos Downloads");
define("_TOTALNEWDOWNLOADS","Total de Novos Downloads");
define("_DTOTALFORLAST","Total de novos downloads enviados por ltimos");
define("_DBESTRATED","Downloads melhores posicionados - Top");
define("_TRATEDDOWNLOADS","total de downloads taxados");
define("_SORTDOWNLOADSBY","Tipo de Download");
define("_DCATNEWTODAY","Novos Downloads nesta categoria adicionados Hoje");
define("_DCATLAST3DAYS","Novos Downloads nesta categoria adicionados nos ltimos 3 dias");
define("_DCATTHISWEEK","Novos Downloads nesta categoria adicionados nesta semana");
define("_DDATE1","Data (Downloads Antigos Listados Primeiro)");
define("_DDATE2","Data (Downloads Novos Listados Primeiro)");
define("_DOWNLOADPROFILE","Perfil do Download");
define("_DOWNLOADRATINGDET","Detalhes das Taxas de Download");
define("_EDITTHISDOWNLOAD","Editar este Download");
define("_DOWNLOADRATING","Taxando Download");
define("_DOWNLOADVOTE","Vote!");
define("_REQUESTDOWNLOADMOD","Pedido para modificao de Download");
define("_DOWNLOADID","Download ID");
define("_DLETSDECIDE","Recomendao de usurios como voc ajudar melhor a outros visitantes a fazer um download de determinado arquivo ento click aqui.");
define("_DRATENOTE4","Voc pode ver uma lista do<a href=\"modules.php?name=Downloads&amp;d_op=TopRated\">Dos Arquivos Mais Avaliados</a>.");
define("_DATE","Data");
define("_TO","Para");
define("_NEW","Novo");
define("_POPULAR","Popular");
define("_TOPRATED","Melhor Colocado");
define("_ADDITIONALDET","Detalhes Adicionais");
define("_EDITORREVIEW","Editor da Reviso");
define("_REPORTBROKEN","Reporte Links Invlidos");
define("_AND","e");
define("_INDB","em nosso Banco de Dados");
define("_INSTRUCTIONS","Instrues");
define("_USERANDIP","So registrado o nome do usurio bem como o ip de quem enviou o Link, ento por favor no abuse ns podemos encontra-lo.");
define("_LDESCRIPTION","Descrio: (255 mx. caracteres)");
define("_CHECKFORIT","Voc no escreveu seu Email. De qualquer maneira nossa equipe ir conferir o seu Link");
define("_LASTWEEK","Da ltima Semana");
define("_LAST30DAYS","Dos ltimos 30 dias");
define("_1WEEK","1 Semana");
define("_2WEEKS","2 Semanas");
define("_30DAYS","30 Dias");
define("_SHOW","Mostar");
define("_DAYS","dias");
define("_ADDEDON","Adicionado em");
define("_RATING","Pdium");
define("_DETAILS","Detalhes");
define("_OF","do");
define("_TVOTESREQ","mnimo de votos requeridos");
define("_SHOWTOP","Mostrar Top");
define("_MOSTPOPULAR","Os Mais Populares - Top");
define("_OFALL","de todos");
define("_POPULARITY","Popularidade");
define("_SELECTPAGE","Pgina Selecionado");
define("_MAIN","ndice");
define("_NEWTODAY","Novo de Hoje");
define("_NEWLAST3DAYS","Novo dos ltimos 3 dias");
define("_NEWTHISWEEK","Novo desta Semana");
define("_POPULARITY1","Popular (Mais Visitados Primeiro)");
define("_POPULARITY2","Popular (Mais Visitados por ltimos)");
define("_TITLEAZ","Ttulo (A a Z)");
define("_TITLEZA","Ttulo (Z a A)");
define("_RATING1","Classificao (Da Pontuao mais Baixa para Mais Alta)");
define("_RATING2","Classificao (Da Pontuao mais Alta para Mais Baixa)");
define("_SEARCHRESULTS4","Resultado da busca por");
define("_USUBCATEGORIES","Subcategorias");
define("_TRY2SEARCH","Experimente Procurar");
define("_INOTHERSENGINES","em outros sistemas de busca");
define("_EDITORIAL","Editorial");
define("_EDITORIALBY","Editorial por");
define("_NOEDITORIAL","Nenhum editorial est atualmente disponvel para este site.");
define("_RATETHISSITE","Classifique este Recurso");
define("_ISTHISYOURSITE","Este  o seu Recurso?");
define("_ALLOWTORATE","Permita que os outros usurios classifiquem isto apartir do seu site !");
define("_OVERALLRATING","Avaliao Global");
define("_TOTALOF","Total de");
define("_USER","Usurios");
define("_USERAVGRATING","A avaliao mdia do usurio");
define("_NUMRATINGS","# de Avaliaes");
define("_REGISTEREDUSERS","Usurios Registrados");
define("_NUMBEROFRATINGS","Nmero de Avaliaes");
define("_NOREGUSERSVOTES","Nenhum usurio annimo vota");
define("_BREAKDOWNBYVAL","Desarranjo de Avaliaes por valor");
define("_LTOTALVOTES","total de votos");
define("_HIGHRATING","Avaliao Alta");
define("_LOWRATING","Avaliao Baixa");
define("_NUMOFCOMMENTS","Nmero de Comentrios");
define("_WEIGHNOTE","* Nota: Este recurso conta para usurios registrados. Avaliao de usurio annimos");
define("_NOUNREGUSERSVOTES","Nenhum usurio annimo vota");
define("_WEIGHOUTNOTE","* Nota: Este recurso pesa para usurios registrados. Fora a avaliao dos eleitores");
define("_NOOUTSIDEVOTES","Nenhum voto Annimo");
define("_OUTSIDEVOTERS","Votos Annimos");
define("_UNREGISTEREDUSERS","Usurios Annimos");
define("_PROMOTEYOURSITE","Promova seu Site");
define("_PROMOTE01","Talvez voc possa se interessar por alguns dos nossos sistemas de 'Avaliao de Sites' que possumos. Estes sistemas permitem colocar uma imagem (ou at mesmo uma forma de avaliao) em seu site na Web de modo que possa aumentar o nmero de visitar que voc recebe. Por favor selecione uma das opes listada abaixo:");
define("_TEXTLINK","Texto Link");
define("_PROMOTE02","Uma maneira de lincar a forma de avaliao  usar um link de texto simples:");
define("_HTMLCODE1","O cdigo em HTML que voc deveria usar neste caso,  o seguinte:");
define("_THENUMBER","Um nmero");
define("_IDREFER","em HTML referente ao nmero de indentificao do seu site que no banco de dados do $sitename. Esteja seguro que este nmero esteja presente.");
define("_BUTTONLINK","Boto do Link");
define("_PROMOTE03","Se voc est procurando um pouco mais que Link de texto simples, talvez voc queira um link com boto pequeno:");
define("_RATEIT","Avalie Este Site!");
define("_HTMLCODE2","O cdigo fonte para o boto acima :");
define("_REMOTEFORM","Forma de Avaliao a Distncia");
define("_PROMOTE04","Se voc nos enganar, ns removeremos seu link. Temos dito isto, aqui como uma forma de avaliao remota e sria.");
define("_VOTE4THISSITE","Vote neste Site!");
define("_HTMLCODE3","Usando desta forma permite que os usurios avaliem o contedo da sua pgina direto do seu site e esta avaliao ser armazenada aqui. A forma acima  invlida, mas o cdigo fonte seguinte funciona basta que voc copie e cole na sua home-page. O cdigo fonte  mostrado abaixo:");
define("_PROMOTE05","Obrigado! E boa sorte com suas avaliaes!");
define("_STAFF","Equipe");
define("_THANKSBROKEN","Obrigado por manter a integridade deste diretrio.");
define("_SECURITYBROKEN","Por razes de segurano seu Nome e Endereo de IP sero gravados temporariamente.");
define("_THANKSFORINFO","Obrigado pela Informao.");
define("_LOOKTOREQUEST","Nossa equipe olhar em breve seu pedido.");
define("_SENDREQUEST","Enviar Pedido");
define("_THANKSTOTAKETIME","Obrigado por usar seu tempo para avaliar um site aqui a");
define("_RETURNTO","Voltar para");
define("_RATENOTE1","Por favor no vote por mais de uma vez na mesma avaliao.");
define("_RATENOTE2","A escala vai de 1 - 10, sendo 1 para pobre e 10 para excelente.");
define("_RATENOTE3","Por favor seja objetivo no seu voto, pois se todo mundo receber somente 1 ou somente 10, as avaliaes no sero teis.");
define("_RATENOTE5","No vote em voc mesmo ou em qualquer um.");
define("_YOUAREREGGED","Voc  um usurio registrado e est conectado em.");
define("_FEELFREE2ADD","Sinta-se a vontade para adicionar comentrios a este site.");
define("_YOUARENOTREGGED","Voc no  um usurio registrado ou no efetuou sue login.");
define("_IFYOUWEREREG","Se voc fosse um usurio registrado poderia enviar vrios comentrios a este site.");
define("_TITLE","Ttulo");
define("_MODIFY","Modificar");
define("_COMPLETEVOTE1","Your vote is appreciated.");
define("_COMPLETEVOTE2","You have already voted for this resource in the past $anonwaitdays day(s).");
define("_COMPLETEVOTE3","Vote for a resource only once.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE4","You cannot vote on a link you submitted.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE5","No rating selected - no vote tallied");
define("_COMPLETEVOTE6","Only one vote per IP address allowed every $outsidewaitdays day(s).");
define("_LINKSDATESTRING","%d-%b-%Y");

?>
